#ifndef PROPERTY_H
#define PROPERTY_H

#include <string>

#include "EnobioAPI_global.h"

/*!
 * \class Property Property.h
 *
 * \brief Class that encapsulates a property value
 *
 */
class ENOBIOAPISHARED_EXPORT Property
{
public:
    /*!
     * Constructor that initializes the property with a string value.
     *
     * \param name Name of the property.
     *
     * \param value Value of the property.
     */
    Property (std::string name, std::string value);

    /*!
     * Constructor that initializes the property with an integer value.
     *
     * \param name Name of the property.
     *
     * \param value Value of the property.
     */
    Property (std::string name, int value);

    /*!
     * Constructor that initializes the property with a float value.
     *
     * \param name Name of the property.
     *
     * \param value Value of the property.
     */
    Property (std::string name, float value);

    /*!
     * It sets the property value from a string value
     *
     * \param value The string value
     */
    void setValue (std::string value);

    /*!
     * It sets the property value from an integer value
     *
     * \param value The integer value
     */
    void setValue (int value);

    /*!
     * It sets the property value from a float value
     *
     * \param value The float value
     */
    void setValue (float value);

    /*!
     * It returns the name of the property
     *
     * \return Name of the property
     */
    std::string getName () const;

    /*!
     * It returns the property value as a string
     *
     * \return property value in string format
     */
    std::string getValueAsString () const;

    /*!
     * It returns the property value as an integer
     *
     * \return property value in integer format
     *
     * \exception ConversionException
     */
    int getValueAsInteger () const;

    /*!
     * It returns the property value as a float
     *
     * \return property value in float format
     *
     * \exception ConversionException
     */
    float getValueAsFloat () const;

private:
    /*!
     * String where the property name is stored
     */
    std::string _name;
    /*!
     * Integer used to store he propery value in integer format.
     */
    int _iValue;
    /*!
     * Float used to store he propery value in float format.
     */
    float _fValue;
    /*!
     * String used to store he propery value in string format.
     */
    std::string _strValue;

};

#endif // PROPERTY_H
