#ifndef STATUSDATA_H
#define STATUSDATA_H

#include "EnobioAPI_global.h"

#include <string>

/*!
 * \class StatusData StatusData.h
 *
 * \brief Class that stores the status data generated by the Enobio class
 */
class ENOBIOAPISHARED_EXPORT StatusData {
public:
    /*!
     * \enum StatusData::statusCode
     *
     * Possible values that the object can hold.
     */
    enum statusCode
    {
        STATUS_HARDWARE_ERROR = 0,
        STATUS_USB_ID,
        STATUS_ENOBIO_OFF,
        STATUS_CALIBRATION_CH1,
        STATUS_CALIBRATION_CH2,
        STATUS_CALIBRATION_CH3,
        STATUS_CALIBRATION_CH4,
        STATUS_NO_DLL,
        STATUS_FW_VERSION,
        STATUS_TRANSMISSION_CHANNEL,
        STATUS_CH1_CALIBRATED,
        STATUS_CH2_CALIBRATED,
        STATUS_CH3_CALIBRATED,
        STATUS_CH4_CALIBRATED,
        STATUS_CH1_CALIBRATING,
        STATUS_CH2_CALIBRATING,
        STATUS_CH3_CALIBRATING,
        STATUS_CH4_CALIBRATING,
        STATUS_CH1_NOT_CALIBRATING,
        STATUS_CH2_NOT_CALIBRATING,
        STATUS_CH3_NOT_CALIBRATING,
        STATUS_CH4_NOT_CALIBRATING,
        STATUS_CH_IDLE,
        STATUS_DEVICE_NOT_OPENED,
        NUMBER_OF_STATUS_CODES
    };

    /*!
     * Constructor that initializes the status data.
     *
     * \param code A value from the statusCode enumeration.
     */
    StatusData (statusCode code);

    /*!
     * Access to the status value stored by the object.
     *
     * \return a status code from the statusCode enumeration.
     */
    statusCode getCode () const;

    /*!
     * It returns a string that explains the status code that the object holds.
     *
     * \return The string wiht the explanation of the status code.
     */
    const std::string getString () const;

    /*!
     * It transforms an status code to its string representation.
     *
     * \param code A value from the statusCode enumeration.
     *
     * \return The string wiht the explanation of the status code.
     */
    static const std::string getStringFromCode (statusCode code);

    /*!
     * It gives the type (ERROR or WARNING) of the status event
     *
     * \param code A value from the statusCode enumeration.
     *
     * \return A string that defines the type of this status message.
     */
    static const std::string getTypeFromCode (statusCode code);

private:
    /*!
     * Variable tha holds the status data code.
     */
    statusCode _code;

    /*!
     * Static variable that holds the strings that explain the different status codes.
     */
    static const std::string strStatus[];

    /*!
     * Static variable that holds the strings that define the status message type
     */
    static const std::string strType[];
};
#endif // STATUSDATA_H
