#ifndef FILEWRITER_H
#define FILEWRITER_H

#include <QFile>
#include <QTextStream>
#include <QObject>
#include <string>

#include "../interfaces/IDataProcessor.h"


class FileWriter : IDataProcessor
{
public:
    /*!
     * Constructor
     *
     * \param fileName Name of the file which will be written. It might include
     * a whole file path.
     */
    FileWriter (std::string fileName);

    /*!
     * Destructor
     */
    ~FileWriter ();

    /*!
     * Allows writing to the file whenever new data is received
     */
    bool start ();

    /*!
     * Stops writing to the file
     */
    void stop ();

    enum dataConsumerIDs
    {
        ID_DATA_INPUT = 0,
    };

    virtual IDataConsumer * getDataConsumer (ID id);

    virtual IDataProducer * getDataProducer (ID id);

    virtual bool registerConsumer (ID id, IDataConsumer& dataConsumer);

    virtual bool deregisterConsumer (ID id, const IDataConsumer& dataConsumer);

private:
    class FileWriterDataConsumer : public IDataConsumer
    {
    public:
        FileWriterDataConsumer (FileWriter * instanceFileWriter);

        virtual void receiveData(const PData &data);
    private:
        FileWriter* _instanceFileWriter;
    };

    FileWriterDataConsumer _fileWriterDataConsumer;

    bool _isOpen;
    QFile _file;
    QTextStream _out;

};



#endif // FILEWRITER_H
