#ifndef PROPERTYCOLLECTION_H
#define PROPERTYCOLLECTION_H

#include <vector>

#include "Property.h"

/*!
 * \class PropertyCollection PropertyCollection.h
 *
 * \brief This class encapsulates a collection of Property objects.
 */
class PropertyCollection
{
public:
    /*!
     * Default constructor
     */
    PropertyCollection();

    /*!
     * It removes the propertier that are stored in the collection.
     */
    ~PropertyCollection ();

    /*!
     * It adds a new Property to the collection
     *
     * \param property Constant reference to the Property to be added.
     */
    void add (const Property& property);

    /*!
     * It returns the Property object whose name matches with the one provided.
     *
     * \param propertyName String with the name of the property to be
     * retrieved.
     *
     * \return Reference to the Property object whose name matches with the one
     * provided. If the Property name does not match with anyone from the
     * collection then a Property with empty name and value is returned.
     */
    const Property& get (std::string propertyName);

    /*!
     * It modifies the Property that mathces the one passed as parameter in the
     * collection.
     *
     * \param property Constant reference to the Property whose value is going
     * to be set in the collection.
     *
     * \return True if the Property name is found in the collection thus the
     * value is correctly set, false otherwise.
     */
    bool set (const Property& property);

private:
    /*!
     * The implementation of the collection is made with a vector of Property
     * objects.
     */
    std::vector<Property> vProperty;
};

#endif // PROPERTYCOLLECTION_H
