#ifndef IDATACONSUMER_H
#define IDATACONSUMER_H

#include "PData.h"

/*!
 * \class IDataConsumer IDataConsumer.h
 *
 * \brief Base class of a data consumer. It works together with a data producer
 * which is attached to in order to receive the data it sends.
 *
 */
class IDataConsumer
{
public:
    /*!
     * Virtual destructor
     */
    virtual ~IDataConsumer () {}

    /*!
     * This method is called by the IDataProducer to which the IDataConsumer is
     * attached to pass data between the owners of these objects. What is done with
     * the data is left to each IDataConsumer implementation.
     *
     * \param data PData object containing the data that comes from the
     * IDataProducer to which it is attached.
     */
    virtual void receiveData (const PData& data) = 0;
};


#endif // IDATACONSUMER_H
