#ifndef __OpenViBE_AcquisitionServer_CDriverEnobioAcquisition_H__
#define __OpenViBE_AcquisitionServer_CDriverEnobioAcquisition_H__
#if defined TARGET_HAS_ThirdPartyEnobioAPI

#include "../ovasIDriver.h"
#include "../ovasCHeader.h"
#include <openvibe/ov_all.h>
#include <Enobio.h>
#include "ovasCEnobioDataConsumer.h"
#include "ovasCEnobioStatusConsumer.h"

 namespace OpenViBEAcquisitionServer
 {
	/**
	 * \class CDriverEnobioAcquisition
	 * \author Masayo Haneda (Starlab)
	 * \date Thu Mar 10 13:27:16 2011
	 * \erief The CDriverEnobioAcquisition allows the acquisition server to acquire data from a Enobio1.6 device.
	 *
	 * TODO: details
	 *
	 * \sa CConfigurationEnobioAcquisition
	 */
	class CDriverEnobioAcquisition : public OpenViBEAcquisitionServer::IDriver
	{
	public:

		CDriverEnobioAcquisition(OpenViBEAcquisitionServer::IDriverContext& rDriverContext);
		virtual ~CDriverEnobioAcquisition(void);
		virtual const char* getName(void);

		virtual OpenViBE::boolean initialize(
			const OpenViBE::uint32 ui32SampleCountPerSentBlock,
			OpenViBEAcquisitionServer::IDriverCallback& rCallback);
		virtual OpenViBE::boolean uninitialize(void);

		virtual OpenViBE::boolean start(void);
		virtual OpenViBE::boolean stop(void);
		virtual OpenViBE::boolean loop(void);

		virtual OpenViBE::boolean isConfigurable(void);
		virtual OpenViBE::boolean configure(void);
		virtual const OpenViBEAcquisitionServer::IHeader* getHeader(void) { return &m_oHeader; }
		
		virtual OpenViBE::boolean isFlagSet(
			const OpenViBEAcquisitionServer::EDriverFlag eFlag) const
		{
			return eFlag==DriverFlag_IsUnstable;
		}

	protected:

		OpenViBEAcquisitionServer::IDriverCallback* m_pCallback;

		// Replace this generic Header with any specific header you might have written
		OpenViBEAcquisitionServer::CHeader m_oHeader;

		OpenViBE::uint32 m_ui32SampleCountPerSentBlock;
		OpenViBE::float32* m_pSample;
		::StatusData::statusCode* m_errors;
		::StatusData::statusCode* m_infos;
	private:
		mutable Enobio m_EnobioDevice;
		
		mutable CEnobioDataConsumer m_EnobioDataConsumer;
		mutable CEnobioStatusConsumer m_EnobioStatusConsumer;
		/*
		 * Insert here all specific attributes, such as USB port number or device ID.
		 * Example :
		 */
		// OpenViBE::uint32 m_ui32USBPort;
	};
};
#endif // TARGET_HAS_ThirdPartyEnobioAPI
#endif // __OpenViBE_AcquisitionServer_CDriverEnobioAcquisition_H__
